# PublicFileOrgLinkSpec

Configuration for a PublicFileOrgLink 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**file_tag** | **str** | A file tag | 
**link_org_id** | **bool, date, datetime, dict, float, int, list, str, none_type** | requests for this org id will be linked to &#x60;target_org_id&#x60;  | 
**target_org_id** | **bool, date, datetime, dict, float, int, list, str, none_type** | requests for &#x60;link_org_id&#x60; will be linked to this.  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


